# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is the Bugzilla HTTP REST API proxy.
#
# The Initial Developer of the Original Code is
# the Mozilla Foundation.
# Portions created by the Initial Developer are Copyright (C) 2009
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   The Original Software was written to the Glory of God by 
#   Gervase Markham <written.to.the.glory.of.God@gerv.net>.
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

package Bugzilla::API::Controller::Attachment;

use strict;
use warnings;
use parent 'Bugzilla::API::Controller::REST';

use Bugzilla::API::Controller::Utils;

sub one_attachment :Path :Args(1) :ActionClass('CrossSiteREST') { }

##############################################################################
# Get single attachment
##############################################################################
sub one_attachment_GET {
  my ($self, $c) = @_;
  
  my $attachid = $c->req->args->[0];
  
  my $result = Bugzilla::API::Model::Attachment->get($c, $attachid);
  
  include_exclude_fields($c, $result, ["data", "encoding"]);
  
  ok_or_error($self, $c, $result);
}

##############################################################################
# Update single attachment (metadata)
##############################################################################
sub one_attachment_PUT {
  my ($self, $c) = @_;
  
  my $attachid = $c->req->args->[0];

  my $result;
  
  if ($c->req->data) {
    $result = Bugzilla::API::Model::Attachment->update($c, 
                                                       $attachid, 
                                                       $c->req->data);
  } else {
    $result = { error => 1, 'message' => "No data supplied for attachment" };
  }
  
  accepted_or_error($self, $c, $result);  
}

1;
