# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is the Bugzilla HTTP REST API proxy.
#
# The Initial Developer of the Original Code is
# the Mozilla Foundation.
# Portions created by the Initial Developer are Copyright (C) 2009
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   The Original Software was written to the Glory of God by 
#   Gervase Markham <written.to.the.glory.of.God@gerv.net>.
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

package Bugzilla::API::Model::User;

use strict;
use warnings;
use parent 'Catalyst::Model';

use Data::Dumper;

use BZ::Client;
use Bugzilla::API::Request;
use Bugzilla::API::Model::Utils;

##############################################################################
# User list
##############################################################################
sub list {
  my ($self, $c, $query) = @_;
  
  my $result = $self->_get_users($c, "match", $query);
  
  return($result);
}

##############################################################################
# Get single user
##############################################################################
sub get {
  my ($self, $c, $nameid) = @_;

  my $param = "names";
  if ($nameid =~ /^\d+$/) {
    $param = "ids";
  }
  
  my $result = $self->_get_users($c, $param, $nameid);

  # Cut the list down to just a single result hashref
  if ($result->{'users'}->[0]) {
    $result = $result->{'users'}->[0];
  }

  return($result);
}

##############################################################################
##############################################################################

# Common routine for getting one or more users from the XML-RPC API
sub _get_users {
  my ($self, $c, $param, $query) = @_;
  
  my $method = "User.get";
  my $payload = { $param => [ $query ] };
  
  my $result = make_rpc_request($c, "User.get", $payload);
  
  foreach my $user (@{ $result->{'users'} }) {
    $user->{'ref'} = $c->uri_for("/user", $user->{'id'})->as_string;
  }

  return ($result);
}

1;
